@@ -5,6 +5,7 @@
 #' elsewhere in your function, make sure to use `add = TRUE` so that you
 #' don't override the handler set up by `check_dots_used()`.
 #'
+#' @usage NULL
 #' @param action The action to take when the dots have not been used. One of
 #'   [rlang::abort()], [rlang::warn()], [rlang::inform()] or [rlang::signal()].
 #' @param env Environment in which to look for `...` and to set up handler.
@@ -26,6 +27,9 @@ check_dots_used <- function(env = parent.frame(), action = abort) {
   eval_bare(exit_handler(action), env)
   invisible()
 }
+on_load({
+  check_dots_used <- replace_from("check_dots_used", "rlang")
+})
 
 check_dots <- function(env = parent.frame(), action) {
   if (.Call(ellipsis_dots_used, env)) {
@@ -54,6 +58,7 @@ exit_handler <- function(action) {
 #'
 #' Named arguments in ... are often a sign of misspelled argument names.
 #'
+#' @usage NULL
 #' @inheritParams check_dots_used
 #' @param env Environment in which to look for `...`.
 #' @export
@@ -84,6 +89,9 @@ check_dots_unnamed <- function(env = parent.frame(), action = abort) {
     .subclass = "rlib_error_dots_named",
   )
 }
+on_load({
+  check_dots_unnamed <- replace_from("check_dots_unnamed", "rlang")
+})
 
 
 #' Check that dots are unused
@@ -91,6 +99,7 @@ check_dots_unnamed <- function(env = parent.frame(), action = abort) {
 #' Sometimes you just want to use `...` to force your users to fully name
 #' the details arguments. This function warns if `...` is not empty.
 #'
+#' @usage NULL
 #' @inheritParams check_dots_used
 #' @param env Environment in which to look for `...`.
 #' @export
@@ -116,6 +125,9 @@ check_dots_empty <- function(env = parent.frame(), action = abort) {
     .subclass = "rlib_error_dots_nonempty"
   )
 }
+on_load({
+  check_dots_empty <- replace_from("check_dots_empty", "rlang")
+})
 
 action_dots <- function(action, message, dot_names, note = NULL, .subclass = NULL, ...) {
   message <- paste_line(
